summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmbicubicpatchedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmbicubicpatchedit.h')
-rw-r--r--kpovmodeler/pmbicubicpatchedit.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/kpovmodeler/pmbicubicpatchedit.h b/kpovmodeler/pmbicubicpatchedit.h
index ac00f00a..cb27810f 100644
--- a/kpovmodeler/pmbicubicpatchedit.h
+++ b/kpovmodeler/pmbicubicpatchedit.h
@@ -39,12 +39,13 @@ class TQCheckBox;
class PMBicubicPatchEdit : public PMGraphicalObjectEdit
{
Q_OBJECT
+ TQ_OBJECT
typedef PMGraphicalObjectEdit Base;
public:
/**
* Creates a PMBicubicPatchEdit with parent and name
*/
- PMBicubicPatchEdit( TQWidget* parent, const char* name = 0 );
+ PMBicubicPatchEdit( TQWidget* tqparent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -39,12 +39,13 @@ class TQCheckBox;
public:
/**
- * Creates a PMBicubicPatchEdit with parent and name
+ * Creates a PMBicubicPatchEdit with tqparent and name
*/